==> nextcloud-29.0.9.tgz: nextcloud/apps/files_reminders/l10n/en_GB.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "File reminders",
    "Reminder for {name}" : "Reminder for {name}",
    "View file" : "View file",
    "View folder" : "View folder",
    "Set file reminders" : "Set file reminders",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 File reminders**\n\nSet file reminders.",
    "We will remind you of this file" : "We will remind you of this file",
    "Please choose a valid date & time" : "Please choose a valid date & time",
    "Cancel" : "Cancel",
    "Clear reminder" : "Clear reminder",
    "Set reminder" : "Set reminder",
    "Set reminder for \"{fileName}\"" : "Set reminder for \"{fileName}\"",
    "Set reminder at custom date & time" : "Set reminder at custom date & time",
    "Reminder set for \"{fileName}\"" : "Reminder set for \"{fileName}\"",
    "Failed to set reminder" : "Failed to set reminder",
    "Reminder cleared for \"{fileName}\"" : "Reminder cleared for \"{fileName}\"",
    "Failed to clear reminder" : "Failed to clear reminder",
    "Reminder set" : "Reminder set",
    "Set custom reminder" : "Set custom reminder",
    "Later today" : "Later today",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow" : "Tomorrow",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend" : "This weekend",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week" : "Next week",
    "Set reminder for next week" : "Set reminder for next week"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.10.tgz: nextcloud/apps/files_reminders/l10n/en_GB.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "File reminders",
    "Reminder for {name}" : "Reminder for {name}",
    "View file" : "View file",
    "View folder" : "View folder",
    "Set file reminders" : "Set file reminders",
    "We will remind you of this file" : "We will remind you of this file",
    "Please choose a valid date & time" : "Please choose a valid date & time",
    "Cancel" : "Cancel",
    "Clear reminder" : "Clear reminder",
    "Set reminder" : "Set reminder",
    "Set reminder for \"{fileName}\"" : "Set reminder for \"{fileName}\"",
    "Set reminder at custom date & time" : "Set reminder at custom date & time",
    "Reminder set for \"{fileName}\"" : "Reminder set for \"{fileName}\"",
    "Failed to set reminder" : "Failed to set reminder",
    "Reminder cleared for \"{fileName}\"" : "Reminder cleared for \"{fileName}\"",
    "Failed to clear reminder" : "Failed to clear reminder",
    "Reminder set" : "Reminder set",
    "Set custom reminder" : "Set custom reminder",
    "Later today" : "Later today",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow" : "Tomorrow",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend" : "This weekend",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week" : "Next week",
    "Set reminder for next week" : "Set reminder for next week",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 File reminders**\n\nSet file reminders."
},
"nplurals=2; plural=(n != 1);");
